#!/bin/sh 

create_graph() {
   separator=`printf "%.1f\n" 0 | sed 's/0//g'`
   R --vanilla --slave <<RSCRIPT
   m<-read.table("$1", header=T, sep="\t", dec='$separator')
   v<-as.matrix(m)
   sd<-read.table("$2", header=T, sep="\t", dec='$separator')
   pdf("$3", family="Times", onefile=FALSE, width=8.5, height=6)
   pcol=c('yellowgreen', 'cornflowerblue', 'darkorange', 'firebrick')
   y_max = round(max(m[,2:5]+sd[,2:5]), -1)
   x_range = range(m[,1])
   plot(v[, 2], type='o', col=pcol[1], ylim=c(0, y_max), axes=FALSE, ann=FALSE)
   x_tiks = 1:(x_range[2] - x_range[1] + 1)
   axis(1, at=x_tiks, lab=v[,1])
   axis(2, las=1, at=10*0:y_max)
   title(main = 'Distance')
   title(xlab= expression(s[max]))
   title(ylab='L [m]')
   lines(x_tiks, v[,3], type="o", pch=22, lty=2, pcol[2])
   lines(x_tiks, v[,4], type="o", pch=23, lty=3, pcol[3])
   lines(x_tiks, v[,5], type="o", pch=24, lty=4, pcol[4])
   legend("topright", c('GA', 'IA', 'HA', 'MA'), cex=0.8, col=pcol, pch=21:24, lty=1:4, horiz=T, box.lwd=0, box.col='white', bg='white')
   arrows(x_tiks, v[,2]-sd[,2], x_tiks, v[,2] + sd[,2], code=3, angle=90, length=0.05, pcol[1], lty=2, lwd=1)
   arrows(x_tiks, v[,3]-sd[,3], x_tiks, v[,3] + sd[,3], code=3, angle=90, length=0.05, pcol[2], lty=2, lwd=1)
   arrows(x_tiks, v[,4]-sd[,4], x_tiks, v[,4] + sd[,4], code=3, angle=90, length=0.05, pcol[3], lty=2, lwd=1)
   arrows(x_tiks, v[,5]-sd[,5], x_tiks, v[,5] + sd[,5], code=3, angle=90, length=0.05, pcol[4], lty=2, lwd=1)

RSCRIPT
}

create_graph $@
