/*
 * File name: TextIO.java
 * Date:      2014/08/26 21:45
 * Author:    Jan Faigl
 */
package cz.cvut.fel.pr1;

import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.nio.file.Paths;
import java.util.Scanner;
import java.util.logging.Level;
import java.util.logging.Logger;

public class TextIO {

    private Scanner stdin;
    private String filename;
    private Scanner file;
    private String[] values;

    public TextIO() {
        stdin = new Scanner(System.in);
    }

    public static boolean isInteger(String s) {
        boolean ret = true;
        try {
            Integer.parseInt(s);
        } catch (NumberFormatException e) {
            ret = false;
        }
        return ret;
    }

    public static boolean isFloat(String s) {
        boolean ret = true;
        try {
            Float.parseFloat(s);
        } catch (NumberFormatException e) {
            ret = false;
        }
        return ret;
    }

    public static boolean isDouble(String s) {
        boolean ret = true;
        try {
            Double.parseDouble(s);
        } catch (NumberFormatException e) {
            ret = false;
        }
        return ret;
    }

    public boolean printToFile(String filename, String line) {
        boolean ret = true; //assume all will be fine
        try (PrintWriter pw = new PrintWriter(new FileWriter(filename))) {
            pw.println(line);
        } catch (IOException e) {
            ret = false; //report failure by return value
        }
        return ret;
    }

    public boolean appendToFile(String filename, String line) {
        boolean ret = true; //assume all will be fine
        try (PrintWriter pw = new PrintWriter(new FileWriter(filename, true))) {
            pw.println(line);
        } catch (IOException e) {
            ret = false; //report failure by return value
        }
        return ret;
    }

    public String getLine() {
        return stdin.hasNext() ? stdin.nextLine() : "";
    }

    /// return true on success
    public boolean openFile(String fname) {
        boolean ret = true;
        try {
            file = new Scanner(Paths.get(fname));
            filename = fname;
        } catch (IOException e) {
            ret = false;
        }
        return ret;
    }

    public boolean resetFile() {
        return openFile(filename);
    }

    /// return true if a line has been read and it contains given number of columns
    public boolean readLine() {
        boolean ret = false;
        if (file.hasNext()) {
            String[] cols = file.nextLine().split(";");
            values = new String[cols.length * 2]; //prepare array for column names and values
            ret = true; //assume all will go fine
            for (int i = 0; i < cols.length; ++i) { //process all columns
                String[] vals = cols[i].split(":");
                if (vals.length != 2) { //something is wrong
                    ret = false; //report failure
                    break; //terminate iteration
                } else {
                    values[2 * i] = vals[0]; //column name
                    values[2 * i + 1] = vals[1]; //column value
                }
            } //end for columns
        }
        return ret;
    }

    public String getColumnValue(String column) {
        for (int i = 0; i < values.length; i += 2) {
            if (column.equals(values[i])) {
                return values[i + 1]; //we assume i+1 is always bellow values.length due to the way how the values array is constructed
            }
        }
        // if no column found, report error
        System.err.println("Error in input data: No column '" + column + "' found");
        return "";
    }
}
